/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.digitalsignature;


import android.view.View;

import androidx.constraintlayout.widget.ConstraintSet;

import com.compdfkit.digitalsignature.databinding.SignaturesPdfSampleActivityBinding;
import com.compdfkit.tools.common.utils.animation.CFillScreenManager;
import com.compdfkit.tools.common.utils.animation.ConstraintSetUtils;
import com.compdfkit.tools.common.views.pdfview.CPreviewMode;

public class CViewerScreenStatusManager {

    private SignaturesPdfSampleActivityBinding binding;

    private boolean isFillScreen;

    private ConstraintSet constraintSet = new ConstraintSet();

    private ConstraintSetUtils constraintSetUtils = new ConstraintSetUtils();

    public CFillScreenManager manager = new CFillScreenManager();

    public CViewerScreenStatusManager(SignaturesPdfSampleActivityBinding binding) {
        this.binding = binding;
        constraintSet.clone(binding.getRoot());
        manager.bindRightToolViewList(binding.pdfView.slideBar);
        manager.bindBottomToolViewList(binding.pdfView.indicatorView);
        manager.bindBottomToolViewList(binding.signatureToolBar);
    }

    public void changeWindowStatus(CPreviewMode mode) {
        if (mode == CPreviewMode.Viewer) {
            manager.removeToolView(binding.signatureToolBar);
            constraintSetUtils.hideFromBottom(constraintSet, binding.signatureToolBar);
        } else if (mode == CPreviewMode.Signature) {
            manager.bindBottomToolViewList(binding.signatureToolBar);
            constraintSetUtils.showFromBottom(constraintSet, binding.signatureToolBar);
        }
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }


    public void fillScreenChange() {
        manager.fillScreenChange(!isFillScreen);
        if (!isFillScreen) {
            //enter full screen
            //hide top toolbar
            constraintSetUtils.hideFromTop(constraintSet, binding.flTool);
            constraintSetUtils.hideFromBottom(constraintSet, binding.signatureToolBar);
            isFillScreen = true;
        } else {
            //enter normal state
            constraintSetUtils.showFromTop(constraintSet, binding.flTool);
            if (manager.bottomToolViewList.contains(binding.signatureToolBar)) {
                constraintSetUtils.showFromBottom(constraintSet, binding.signatureToolBar);
            }else {
                constraintSetUtils.hideFromBottom(constraintSet, binding.signatureToolBar);
            }
            if (manager.topToolViewList.contains(binding.signStatusView)) {
                constraintSetUtils.show(constraintSet, binding.signStatusView);
            }else {
                constraintSetUtils.hide(constraintSet, binding.signStatusView);
            }
            isFillScreen = false;
        }
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }

    public void constraintShow(View view){
        constraintSetUtils.show(constraintSet, view);
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }

    public void constraintHide(View view){
        constraintSetUtils.hide(constraintSet, view);
        constraintSetUtils.apply(constraintSet, binding.getRoot());
    }

}
